#########################################################################
#########################################################################

# Parent E. and Rivot E. - An introduction to Hierarchcial Modeling of Ecological Data
# Chapman et al.
# 2012

# BUGS program for the baseball players performances
# From the historical example published by of Efron and Morris in 2004
# Appendix C

#########################################################################
#########################################################################

rm(list = ls())

library(rbugs)
library(boot)
library("BRugs")
library(coda)



# ----------------------------------------------------------
# MCMC config.
# ----------------------------------------------------------

# Burn-in phase
NburnIn <- 5000
# Inferences
Niter <- 10000
thin <- 10
# Number of chains
NChains <- 3



# ----------------------------------------------------------
# Load data
# ----------------------------------------------------------

data <- "data_Baseball.txt"

Y <- source(data)$value$Y
perf <- source(data)$value$perf
N <- source(data)$value$N


# ----------------------------------------------------------
# Run the "Independent" model
# ----------------------------------------------------------

model <- "model_Baseball_Independent.txt"

modelCheck(model)  
modelData(data)   
modelCompile(numChains=NChains)      
modelGenInits()

# Burn-in period

modelUpdate(NburnIn) 

# Inferences

samplesSet("mu.player") 
modelUpdate(numUpdates = Niter, thin = thin)               

# Store MCMC samples of theta in a data.frame

mu.player.ind <- buildMCMC("mu.player")  	
mu.player.ind <- as.matrix(mu.player.ind)	
mu.player.ind <- as.data.frame(mu.player.ind) 



# ----------------------------------------------------------
# Run the Hierarchical model
# ----------------------------------------------------------

model <- "model_Baseball_Hierarchical.txt"

modelCheck(model)  
modelData(data)   
modelCompile(numChains=NChains)      
modelGenInits()

# Burn-in period
modelUpdate(NburnIn) 

# Inferences

samplesSet("mu.player") 
modelUpdate(numUpdates = Niter, thin = thin)     

# Store MCMC samples of theta in a data.frame

mu.player.hbm <- buildMCMC("mu.player")  	
mu.player.hbm <- as.matrix(mu.player.hbm )	
mu.player.hbm <- as.data.frame(mu.player.hbm ) 



# ----------------------------------------------------------
# Figure to compare results of the 2 models
# ----------------------------------------------------------

# windows()

res <- 6
name_figure <- "ShrinkageBaseball.png"
png(filename = name_figure, height = 500*res, width = 650*res, res=72*res)

par(mfrow = c(1,1), bty="n", mar=c(6,3,1,1))

names <- c("Clemente","Robinson","Howard","Johnstone","Berry","Spencer","Kessinger","Alvarado","Santo","Swoboda","Unser","Williams","Scott","Petrocelli","Rodriguez","Campaneris","Munson","Alvis")

boxplot(mu.player.ind, xaxt = "n", yaxt = "n", boxwex=0.20, ylim = c(0,0.6), outline = F)
boxplot(mu.player.hbm,xaxt = "n", yaxt = "n",
        add=T,show.names=F,col='grey',outline=F,boxwex=0.20,at= 1:N+0.30)
points(1:N+0.175, perf, col="black", pch=19, cex=1.2)

axis(side =1, at=(1:N)+0.175, labels = names, las=2)
axis(side =2)

dev.off()
